open_exercises.RdCalling open_exercises with a session number as argument will open the exercise html for that session.
The html will be opened in your default browser. This function is inspired by Schmitz & Esser (see references).
open_exercises(session)
| session_number | The number of the session. |
|---|
Nothing.
Schmitz, D., & Esser, J. (2021). SfL: Statistics for Linguistics. R package version 0.3. URL: https://github.com/dosc91/SfL
D. Schmitz
open_exercises(02) #> x I am not aware of exercises for session 02! Currently, I only know of exercises for sessions ...!